@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # SPDX-License-Identifier: GPL-2.0-only
 #
@@ -25,13 +25,13 @@ TMPFILE=$(mktemp)
 trap 'rm -f "$TMPFILE"; _exit' EXIT
 
 
-NUM_TESTS=15
+NUM_TESTS=12
 
 plan_tests	${NUM_TESTS}
 
-for a in test_urcu_gc test_urcu_signal_gc test_urcu_mb_gc test_urcu_qsbr_gc \
-	test_urcu_lgc test_urcu_signal_lgc test_urcu_mb_lgc test_urcu_qsbr_lgc \
-	test_urcu test_urcu_signal test_urcu_mb test_urcu_qsbr \
+for a in test_urcu_gc test_urcu_mb_gc test_urcu_qsbr_gc \
+	test_urcu_lgc test_urcu_mb_lgc test_urcu_qsbr_lgc \
+	test_urcu test_urcu_mb test_urcu_qsbr \
 	test_rwlock test_perthreadlock test_mutex; do
 	okx ${URCU_TESTS_TIME_BIN} "$URCU_TESTS_BUILDDIR/benchmark/${a}" "$@" 2>"${TMPFILE}"
 	diag "time: $(cat "${TMPFILE}")"
